@@ -28,6 +28,7 @@
 #include <gpgme++/data.h>
 #include <string.h>
 
+class Recipient;
 class Mail;
 class Overlay;
 
@@ -59,6 +60,11 @@ public:
       variable. Additional diagnostic output is passed
       through r_diag.
 
+      -1 return value on error.
+      -2 on cancel.
+      -3 When we need additional mails to resolve all
+         recipients.
+
       @returns 0 on success.
   */
   int do_crypto (GpgME::Error &err, std::string &r_diag);
@@ -76,12 +82,25 @@ public:
   /** @brief check weather something was encrypted. */
   bool is_encrypter () const { return m_encrypt; }
 
+  /** @brief check if the cryptcontroller has all keys for
+    the operation. */
+  bool is_resolved () const;
+
+  /** @brief check if the cryptcontroller can actually do
+    the work with a single protocol. This is different
+    to is_resolved which is also true when multiple mails
+    might be necessary to fulfil the operation.
+    */
+  GpgME::Protocol get_resolved_protocol () const;
 private:
+  void clear_keys ();
+  void resolving_done ();
   int resolve_keys ();
   int resolve_keys_cached ();
+  bool resolve_through_protocol (GpgME::Protocol proto);
   int parse_output (GpgME::Data &resolverOutput);
-  int lookup_fingerprints (const std::string &sigFpr,
-                           const std::vector<std::string> recpFprs);
+  int lookup_fingerprints (const std::vector<std::string> &sigFprs,
+                           const std::vector<std::pair<std::string, std::string> > &recpFprs);
 
   void parse_micalg (const GpgME::SigningResult &sResult);
 
@@ -93,10 +112,11 @@ private:
   std::string m_micalg;
   bool m_encrypt, m_sign, m_crypto_success;
   GpgME::Protocol m_proto;
-  GpgME::Key m_signer_key;
-  std::vector<GpgME::Key> m_recipients;
+  std::string m_sender;
+  std::vector<GpgME::Key> m_signer_keys;
+  std::vector<GpgME::Key> m_enc_keys;
+  std::vector<Recipient> m_recipients;
   std::unique_ptr<Overlay> m_overlay;
-  std::vector<std::string> m_recipient_addrs;
 };
 
 #endif
